/*
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) The PHP Group                                          |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_01.txt                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Ilia Alshanetsky <ilia@php.net>                              |
   +----------------------------------------------------------------------+
*/

#ifndef PHP_UUENCODE_H
#define PHP_UUENCODE_H

PHP_FUNCTION(convert_uudecode);
PHP_FUNCTION(convert_uuencode);

PHPAPI zend_string *php_uudecode(char *src, size_t src_len);
PHPAPI zend_string *php_uuencode(char *src, size_t src_len);

#endif /* PHP_UUENCODE_H */
